@@ -19,14 +19,17 @@
  *      Mathias Hasselmann
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "libepc/publisher.h"
 #include "libepc/dispatcher.h"
 #include "libepc/enums.h"
-#include "libepc/i18n.h"
 #include "libepc/shell.h"
 #include "libepc/tls.h"
 
-#include <glibconfig.h>
+#include <glib/gi18n-lib.h>
 #include <libsoup/soup.h>
 #include <string.h>
 
@@ -373,7 +376,7 @@ epc_publisher_chunk_cb (SoupMessage *message,
   if (chunk && length)
     {
       if (EPC_DEBUG_LEVEL (1))
-        g_debug ("%s: writing %d bytes", G_STRLOC, length);
+        g_debug ("%s: writing %" G_GSIZE_FORMAT " bytes", G_STRLOC, length);
 
 #ifdef HAVE_LIBSOUP22
       soup_message_add_chunk (message, SOUP_MEMORY_COPY, chunk, length);
