@@ -18,6 +18,11 @@
  * Authors:
  *      Mathias Hasselmann
  */
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "libepc/shell.h"
 
 #include <avahi-common/error.h>
@@ -462,7 +467,11 @@ epc_shell_progress_update_default (gdouble      progress,
   title = *context;
 
   if (NULL == title)
-    title = _("Operation Proceeded");
+  {
+    // Translators: This is just a generic default message for a progress bar.
+    title = _("Operation in Progress");
+  }
+
   if (NULL == message)
     message = _("No details known");
 
